<?php

/**
 * @file
 * Admin page callbacks for the Webform Hints module.
 */

/**
 * Menu callback; displays the Webform hints module settings page.
 *
 * @ingroup forms
 * @see webform_hints_admin_settings_submit()
 */
function webform_hints_admin_settings($form, &$form_state) {
  // Query the database for all webform nodes.
  $options = array();
  $result = db_query('SELECT w.nid, n.title FROM {webform} w, {node} n WHERE w.nid = n.nid');
  foreach ($result as $webform) {
    $options[$webform->nid] = $webform->title;
  }

  if (empty($options)) {
    drupal_set_message(t('You have yet to add any Webforms to this site. Once you do, you can configure which forms will receive automatic placeholders here. <a href="@admin-url">Create your first Webform</a> to get started.', array('@admin-url' => url('node/add/webform'))), 'warning');
  }

  // Build checkbox list of results with ability to apply/remove Webform Hints.
  $form['webform_hints_forms'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Webforms'),
    '#default_value' => variable_get('webform_hints_forms', array()),
    '#options' => $options,
    '#description' => t('Select the webform nodes you would like to apply the "Webform Hints" effect to. On the selected nodes, the titles of textfields, textareas, select fields, and email fields will appear as placeholder text within the respective fields. The labels of these fields will be visible only to screenreaders.'),
  );
  $form['webform_hints_required'] = array(
    '#type' => 'textfield',
    '#size' => 20,
    '#title' => t('Required indicator'),
    '#default_value' => variable_get('webform_hints_required', ' (required)'),
    '#description' => t('This is appended to the hint of a required label. It can be left blank. The element can also be themed using the .required class (see <a href="http://www.w3.org/TR/WCAG/#visual-audio-contrast">WCAG</a>).'),
  );

  $form['webform_hints_legacy_support'] = array(
    '#type' => 'checkbox',
    '#title' => t('Legacy Browser Support'),
    '#default_value' => variable_get('webform_hints_legacy_support', ''),
    '#description' => t('Webform hints uses the HTML5 "placeholder" attribute for setting default/placeholder values on webform inputs. This module includes support for legacy browsers (like IE 9 and below) by enabling this option. This requires downloading and installing the Form Defaults jQuery plugin by Jason Palmer. See README.txt for installation instructions.'),
  );

  $form = system_settings_form($form);

  return $form;
}

/**
 * Form validations for system settings.
 */
function webform_hints_admin_settings_validate($form, &$form_state) {
  $values = $form_state['values'];
  if ($values['webform_hints_legacy_support'] && !webform_hints_form_defaults_installed()) {
    form_set_error('webform_hints_legacy_support', t('The Form Defaults jQuery plugin needs to be installed to enable legacy support.'));
  }
}
